# Table of Contents

- [extended-guide-on-survey-features](<./extended-guide-on-survey-features.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Extended Guide on Survey Features](<./Extended-Guide-on-Survey-Features.md>)
  - [Configuring Survey Permissions for Non-Admin Roles](<./Extended-Guide-on-Survey-Features/Configuring-Survey-Permissions-for-Non-Admin-Roles.md>)
  - [Safety Net for Survey Notifications](<./Extended-Guide-on-Survey-Features/Safety-Net-for-Survey-Notifications.md>)
  - [Activating and Deactivating Safety Net](<./Extended-Guide-on-Survey-Features/Activating-and-Deactivating-Safety-Net.md>)
  - [Available Actions When Safety Net is Triggered](<./Extended-Guide-on-Survey-Features/Available-Actions-When-Safety-Net-is-Triggered.md>)
  - [Assigning Fact Sheet Subscriptions Through Surveys](<./Extended-Guide-on-Survey-Features/Assigning-Fact-Sheet-Subscriptions-Through-Surveys.md>)
  - [Survey API](<./Extended-Guide-on-Survey-Features/Survey-API.md>)
  - [Was this page helpful?](<./Extended-Guide-on-Survey-Features/Was-this-page-helpful.md>)
